@@ -279,18 +279,10 @@ fn env_dep_installed(tool: &str) -> Result<()> {
     Ok(())
 }
 
-// Use the env-provided source directory and remove the quotes
-fn get_source_dir() -> PathBuf {
-    let mut dir = install::target::SOURCE_DIR.to_string();
-    dir.remove(0);
-    dir.remove(dir.len() - 1);
-    Path::new(&dir).to_path_buf()
-}
-
 // Install {wranglerjs} from our GitHub releases
 fn install() -> Result<PathBuf> {
     let wranglerjs_path = if install::target::DEBUG {
-        let source_path = get_source_dir();
+        let source_path = Path::new(env!("CARGO_MANIFEST_DIR"));
         let wranglerjs_path = source_path.join("wranglerjs");
         log::info!("wranglerjs at: {:?}", wranglerjs_path);
         wranglerjs_path
